"""
Python package `abtrap`: building invisibility shields to protect network devices.
"""

import pandas as pd
import numpy as np


def do_nothing():
    """
    This function does nothing.
    """
    pass
